Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2747)

Unified Diff: chrome/browser/predictors/resource_prefetch_predictor.h

Issue 2923813002: predictors: Don't call IsUrlPrefetchable twice. (Closed)
Patch Set: . Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/predictors/resource_prefetch_predictor.h
diff --git a/chrome/browser/predictors/resource_prefetch_predictor.h b/chrome/browser/predictors/resource_prefetch_predictor.h
index 4363b37543195798cefcdd1b1b7892d1fb69c150..2c5b9846244d7a53fc3077facdaef33b8ebadd72 100644
--- a/chrome/browser/predictors/resource_prefetch_predictor.h
+++ b/chrome/browser/predictors/resource_prefetch_predictor.h
@@ -265,9 +265,9 @@ class ResourcePrefetchPredictor
Prediction* prediction) const;
private:
- // Starts prefetching if it is enabled and prefetching data exists for the
- // |main_frame_url| either at the URL or at the host level.
- void StartPrefetching(const GURL& main_frame_url);
+ // Starts prefetching for |main_frame_url| from a |prediction|.
+ void StartPrefetching(const GURL& main_frame_url,
+ const Prediction& prediction);
// Stops prefetching that may be in progress corresponding to
// |main_frame_url|.
« no previous file with comments | « chrome/browser/predictors/loading_predictor_unittest.cc ('k') | chrome/browser/predictors/resource_prefetch_predictor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698